# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateWebhookOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'basic_auth': 'BasicAuthOptions',
        'name': 'str',
        'event_name': 'str',
        'include_headers': 'WebhookHeaders',
        'request_body_template': 'str',
        'ai_transform_id': 'str',
        'use_static_ip_range': 'bool',
        'ignore_insecure_ssl_certificates': 'bool',
        'tags': 'list[str]'
    }

    attribute_map = {
        'url': 'url',
        'basic_auth': 'basicAuth',
        'name': 'name',
        'event_name': 'eventName',
        'include_headers': 'includeHeaders',
        'request_body_template': 'requestBodyTemplate',
        'ai_transform_id': 'aiTransformId',
        'use_static_ip_range': 'useStaticIpRange',
        'ignore_insecure_ssl_certificates': 'ignoreInsecureSslCertificates',
        'tags': 'tags'
    }

    def __init__(self, url=None, basic_auth=None, name=None, event_name=None, include_headers=None, request_body_template=None, ai_transform_id=None, use_static_ip_range=False, ignore_insecure_ssl_certificates=None, tags=None, local_vars_configuration=None):  # noqa: E501
        """CreateWebhookOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._basic_auth = None
        self._name = None
        self._event_name = None
        self._include_headers = None
        self._request_body_template = None
        self._ai_transform_id = None
        self._use_static_ip_range = None
        self._ignore_insecure_ssl_certificates = None
        self._tags = None
        self.discriminator = None

        self.url = url
        self.basic_auth = basic_auth
        self.name = name
        self.event_name = event_name
        if include_headers is not None:
            self.include_headers = include_headers
        self.request_body_template = request_body_template
        self.ai_transform_id = ai_transform_id
        self.use_static_ip_range = use_static_ip_range
        self.ignore_insecure_ssl_certificates = ignore_insecure_ssl_certificates
        self.tags = tags

    @property
    def url(self):
        """Gets the url of this CreateWebhookOptions.  # noqa: E501

        Public URL on your server that MailSlurp can post WebhookNotification payload to when an email is received or an event is trigger. The payload of the submitted JSON is dependent on the webhook event type. See docs.mailslurp.com/webhooks for event payload documentation.  # noqa: E501

        :return: The url of this CreateWebhookOptions.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CreateWebhookOptions.

        Public URL on your server that MailSlurp can post WebhookNotification payload to when an email is received or an event is trigger. The payload of the submitted JSON is dependent on the webhook event type. See docs.mailslurp.com/webhooks for event payload documentation.  # noqa: E501

        :param url: The url of this CreateWebhookOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def basic_auth(self):
        """Gets the basic_auth of this CreateWebhookOptions.  # noqa: E501


        :return: The basic_auth of this CreateWebhookOptions.  # noqa: E501
        :rtype: BasicAuthOptions
        """
        return self._basic_auth

    @basic_auth.setter
    def basic_auth(self, basic_auth):
        """Sets the basic_auth of this CreateWebhookOptions.


        :param basic_auth: The basic_auth of this CreateWebhookOptions.  # noqa: E501
        :type: BasicAuthOptions
        """

        self._basic_auth = basic_auth

    @property
    def name(self):
        """Gets the name of this CreateWebhookOptions.  # noqa: E501

        Optional name for the webhook  # noqa: E501

        :return: The name of this CreateWebhookOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateWebhookOptions.

        Optional name for the webhook  # noqa: E501

        :param name: The name of this CreateWebhookOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def event_name(self):
        """Gets the event_name of this CreateWebhookOptions.  # noqa: E501

        Optional webhook event name. Default is `EMAIL_RECEIVED` and is triggered when an email is received by the inbox associated with the webhook. Payload differ according to the webhook event name.  # noqa: E501

        :return: The event_name of this CreateWebhookOptions.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this CreateWebhookOptions.

        Optional webhook event name. Default is `EMAIL_RECEIVED` and is triggered when an email is received by the inbox associated with the webhook. Payload differ according to the webhook event name.  # noqa: E501

        :param event_name: The event_name of this CreateWebhookOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def include_headers(self):
        """Gets the include_headers of this CreateWebhookOptions.  # noqa: E501


        :return: The include_headers of this CreateWebhookOptions.  # noqa: E501
        :rtype: WebhookHeaders
        """
        return self._include_headers

    @include_headers.setter
    def include_headers(self, include_headers):
        """Sets the include_headers of this CreateWebhookOptions.


        :param include_headers: The include_headers of this CreateWebhookOptions.  # noqa: E501
        :type: WebhookHeaders
        """

        self._include_headers = include_headers

    @property
    def request_body_template(self):
        """Gets the request_body_template of this CreateWebhookOptions.  # noqa: E501

        Template for the JSON body of the webhook request that will be sent to your server. Use Moustache style `{{variableName}}` templating to use parts of the standard webhook payload for the given event.  # noqa: E501

        :return: The request_body_template of this CreateWebhookOptions.  # noqa: E501
        :rtype: str
        """
        return self._request_body_template

    @request_body_template.setter
    def request_body_template(self, request_body_template):
        """Sets the request_body_template of this CreateWebhookOptions.

        Template for the JSON body of the webhook request that will be sent to your server. Use Moustache style `{{variableName}}` templating to use parts of the standard webhook payload for the given event.  # noqa: E501

        :param request_body_template: The request_body_template of this CreateWebhookOptions.  # noqa: E501
        :type: str
        """

        self._request_body_template = request_body_template

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this CreateWebhookOptions.  # noqa: E501

        AI Transform ID to apply to the webhook event and send a payload matching transform output schema  # noqa: E501

        :return: The ai_transform_id of this CreateWebhookOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this CreateWebhookOptions.

        AI Transform ID to apply to the webhook event and send a payload matching transform output schema  # noqa: E501

        :param ai_transform_id: The ai_transform_id of this CreateWebhookOptions.  # noqa: E501
        :type: str
        """

        self._ai_transform_id = ai_transform_id

    @property
    def use_static_ip_range(self):
        """Gets the use_static_ip_range of this CreateWebhookOptions.  # noqa: E501

        Use static IP range when calling webhook endpoint  # noqa: E501

        :return: The use_static_ip_range of this CreateWebhookOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_static_ip_range

    @use_static_ip_range.setter
    def use_static_ip_range(self, use_static_ip_range):
        """Sets the use_static_ip_range of this CreateWebhookOptions.

        Use static IP range when calling webhook endpoint  # noqa: E501

        :param use_static_ip_range: The use_static_ip_range of this CreateWebhookOptions.  # noqa: E501
        :type: bool
        """

        self._use_static_ip_range = use_static_ip_range

    @property
    def ignore_insecure_ssl_certificates(self):
        """Gets the ignore_insecure_ssl_certificates of this CreateWebhookOptions.  # noqa: E501

        Ignore insecure SSL certificates when sending request. Useful for self-signed certs.  # noqa: E501

        :return: The ignore_insecure_ssl_certificates of this CreateWebhookOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_insecure_ssl_certificates

    @ignore_insecure_ssl_certificates.setter
    def ignore_insecure_ssl_certificates(self, ignore_insecure_ssl_certificates):
        """Sets the ignore_insecure_ssl_certificates of this CreateWebhookOptions.

        Ignore insecure SSL certificates when sending request. Useful for self-signed certs.  # noqa: E501

        :param ignore_insecure_ssl_certificates: The ignore_insecure_ssl_certificates of this CreateWebhookOptions.  # noqa: E501
        :type: bool
        """

        self._ignore_insecure_ssl_certificates = ignore_insecure_ssl_certificates

    @property
    def tags(self):
        """Gets the tags of this CreateWebhookOptions.  # noqa: E501

        Optional list of tags  # noqa: E501

        :return: The tags of this CreateWebhookOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CreateWebhookOptions.

        Optional list of tags  # noqa: E501

        :param tags: The tags of this CreateWebhookOptions.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateWebhookOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateWebhookOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WaitForSingleSmsOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_number_id': 'str',
        'timeout': 'int',
        'unread_only': 'bool',
        'before': 'datetime',
        'since': 'datetime',
        'sort_direction': 'str',
        'delay': 'int'
    }

    attribute_map = {
        'phone_number_id': 'phoneNumberId',
        'timeout': 'timeout',
        'unread_only': 'unreadOnly',
        'before': 'before',
        'since': 'since',
        'sort_direction': 'sortDirection',
        'delay': 'delay'
    }

    def __init__(self, phone_number_id=None, timeout=None, unread_only=None, before=None, since=None, sort_direction=None, delay=None, local_vars_configuration=None):  # noqa: E501
        """WaitForSingleSmsOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_number_id = None
        self._timeout = None
        self._unread_only = None
        self._before = None
        self._since = None
        self._sort_direction = None
        self._delay = None
        self.discriminator = None

        self.phone_number_id = phone_number_id
        self.timeout = timeout
        if unread_only is not None:
            self.unread_only = unread_only
        if before is not None:
            self.before = before
        if since is not None:
            self.since = since
        if sort_direction is not None:
            self.sort_direction = sort_direction
        if delay is not None:
            self.delay = delay

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The phone_number_id of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this WaitForSingleSmsOptions.


        :param phone_number_id: The phone_number_id of this WaitForSingleSmsOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number_id is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number_id`, must not be `None`")  # noqa: E501

        self._phone_number_id = phone_number_id

    @property
    def timeout(self):
        """Gets the timeout of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The timeout of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this WaitForSingleSmsOptions.


        :param timeout: The timeout of this WaitForSingleSmsOptions.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and timeout is None:  # noqa: E501
            raise ValueError("Invalid value for `timeout`, must not be `None`")  # noqa: E501

        self._timeout = timeout

    @property
    def unread_only(self):
        """Gets the unread_only of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The unread_only of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._unread_only

    @unread_only.setter
    def unread_only(self, unread_only):
        """Sets the unread_only of this WaitForSingleSmsOptions.


        :param unread_only: The unread_only of this WaitForSingleSmsOptions.  # noqa: E501
        :type: bool
        """

        self._unread_only = unread_only

    @property
    def before(self):
        """Gets the before of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The before of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this WaitForSingleSmsOptions.


        :param before: The before of this WaitForSingleSmsOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def since(self):
        """Gets the since of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The since of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this WaitForSingleSmsOptions.


        :param since: The since of this WaitForSingleSmsOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def sort_direction(self):
        """Gets the sort_direction of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The sort_direction of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: str
        """
        return self._sort_direction

    @sort_direction.setter
    def sort_direction(self, sort_direction):
        """Sets the sort_direction of this WaitForSingleSmsOptions.


        :param sort_direction: The sort_direction of this WaitForSingleSmsOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["ASC", "DESC"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_direction, allowed_values)
            )

        self._sort_direction = sort_direction

    @property
    def delay(self):
        """Gets the delay of this WaitForSingleSmsOptions.  # noqa: E501


        :return: The delay of this WaitForSingleSmsOptions.  # noqa: E501
        :rtype: int
        """
        return self._delay

    @delay.setter
    def delay(self, delay):
        """Sets the delay of this WaitForSingleSmsOptions.


        :param delay: The delay of this WaitForSingleSmsOptions.  # noqa: E501
        :type: int
        """

        self._delay = delay

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WaitForSingleSmsOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WaitForSingleSmsOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorInsightsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'monitor_id': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'total_runs': 'int',
        'healthy_runs': 'int',
        'degraded_runs': 'int',
        'critical_runs': 'int',
        'failed_runs': 'int',
        'success_rate': 'float',
        'average_health_score': 'float',
        'current_healthy_streak': 'int',
        'best_healthy_streak': 'int',
        'good_performance_signals': 'list[str]',
        'attention_signals': 'list[str]',
        'top_findings': 'list[str]',
        'latest_run': 'DomainMonitorRunDto'
    }

    attribute_map = {
        'monitor_id': 'monitorId',
        'since': 'since',
        'before': 'before',
        'total_runs': 'totalRuns',
        'healthy_runs': 'healthyRuns',
        'degraded_runs': 'degradedRuns',
        'critical_runs': 'criticalRuns',
        'failed_runs': 'failedRuns',
        'success_rate': 'successRate',
        'average_health_score': 'averageHealthScore',
        'current_healthy_streak': 'currentHealthyStreak',
        'best_healthy_streak': 'bestHealthyStreak',
        'good_performance_signals': 'goodPerformanceSignals',
        'attention_signals': 'attentionSignals',
        'top_findings': 'topFindings',
        'latest_run': 'latestRun'
    }

    def __init__(self, monitor_id=None, since=None, before=None, total_runs=None, healthy_runs=None, degraded_runs=None, critical_runs=None, failed_runs=None, success_rate=None, average_health_score=None, current_healthy_streak=None, best_healthy_streak=None, good_performance_signals=None, attention_signals=None, top_findings=None, latest_run=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorInsightsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._monitor_id = None
        self._since = None
        self._before = None
        self._total_runs = None
        self._healthy_runs = None
        self._degraded_runs = None
        self._critical_runs = None
        self._failed_runs = None
        self._success_rate = None
        self._average_health_score = None
        self._current_healthy_streak = None
        self._best_healthy_streak = None
        self._good_performance_signals = None
        self._attention_signals = None
        self._top_findings = None
        self._latest_run = None
        self.discriminator = None

        self.monitor_id = monitor_id
        self.since = since
        self.before = before
        self.total_runs = total_runs
        self.healthy_runs = healthy_runs
        self.degraded_runs = degraded_runs
        self.critical_runs = critical_runs
        self.failed_runs = failed_runs
        self.success_rate = success_rate
        self.average_health_score = average_health_score
        self.current_healthy_streak = current_healthy_streak
        self.best_healthy_streak = best_healthy_streak
        self.good_performance_signals = good_performance_signals
        self.attention_signals = attention_signals
        self.top_findings = top_findings
        if latest_run is not None:
            self.latest_run = latest_run

    @property
    def monitor_id(self):
        """Gets the monitor_id of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The monitor_id of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: str
        """
        return self._monitor_id

    @monitor_id.setter
    def monitor_id(self, monitor_id):
        """Sets the monitor_id of this DomainMonitorInsightsDto.


        :param monitor_id: The monitor_id of this DomainMonitorInsightsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and monitor_id is None:  # noqa: E501
            raise ValueError("Invalid value for `monitor_id`, must not be `None`")  # noqa: E501

        self._monitor_id = monitor_id

    @property
    def since(self):
        """Gets the since of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The since of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this DomainMonitorInsightsDto.


        :param since: The since of this DomainMonitorInsightsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The before of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this DomainMonitorInsightsDto.


        :param before: The before of this DomainMonitorInsightsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def total_runs(self):
        """Gets the total_runs of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The total_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._total_runs

    @total_runs.setter
    def total_runs(self, total_runs):
        """Sets the total_runs of this DomainMonitorInsightsDto.


        :param total_runs: The total_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `total_runs`, must not be `None`")  # noqa: E501

        self._total_runs = total_runs

    @property
    def healthy_runs(self):
        """Gets the healthy_runs of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The healthy_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._healthy_runs

    @healthy_runs.setter
    def healthy_runs(self, healthy_runs):
        """Sets the healthy_runs of this DomainMonitorInsightsDto.


        :param healthy_runs: The healthy_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and healthy_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `healthy_runs`, must not be `None`")  # noqa: E501

        self._healthy_runs = healthy_runs

    @property
    def degraded_runs(self):
        """Gets the degraded_runs of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The degraded_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._degraded_runs

    @degraded_runs.setter
    def degraded_runs(self, degraded_runs):
        """Sets the degraded_runs of this DomainMonitorInsightsDto.


        :param degraded_runs: The degraded_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and degraded_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `degraded_runs`, must not be `None`")  # noqa: E501

        self._degraded_runs = degraded_runs

    @property
    def critical_runs(self):
        """Gets the critical_runs of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The critical_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._critical_runs

    @critical_runs.setter
    def critical_runs(self, critical_runs):
        """Sets the critical_runs of this DomainMonitorInsightsDto.


        :param critical_runs: The critical_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and critical_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `critical_runs`, must not be `None`")  # noqa: E501

        self._critical_runs = critical_runs

    @property
    def failed_runs(self):
        """Gets the failed_runs of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The failed_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_runs

    @failed_runs.setter
    def failed_runs(self, failed_runs):
        """Sets the failed_runs of this DomainMonitorInsightsDto.


        :param failed_runs: The failed_runs of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_runs`, must not be `None`")  # noqa: E501

        self._failed_runs = failed_runs

    @property
    def success_rate(self):
        """Gets the success_rate of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The success_rate of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: float
        """
        return self._success_rate

    @success_rate.setter
    def success_rate(self, success_rate):
        """Sets the success_rate of this DomainMonitorInsightsDto.


        :param success_rate: The success_rate of this DomainMonitorInsightsDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and success_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `success_rate`, must not be `None`")  # noqa: E501

        self._success_rate = success_rate

    @property
    def average_health_score(self):
        """Gets the average_health_score of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The average_health_score of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: float
        """
        return self._average_health_score

    @average_health_score.setter
    def average_health_score(self, average_health_score):
        """Sets the average_health_score of this DomainMonitorInsightsDto.


        :param average_health_score: The average_health_score of this DomainMonitorInsightsDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `average_health_score`, must not be `None`")  # noqa: E501

        self._average_health_score = average_health_score

    @property
    def current_healthy_streak(self):
        """Gets the current_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The current_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._current_healthy_streak

    @current_healthy_streak.setter
    def current_healthy_streak(self, current_healthy_streak):
        """Sets the current_healthy_streak of this DomainMonitorInsightsDto.


        :param current_healthy_streak: The current_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and current_healthy_streak is None:  # noqa: E501
            raise ValueError("Invalid value for `current_healthy_streak`, must not be `None`")  # noqa: E501

        self._current_healthy_streak = current_healthy_streak

    @property
    def best_healthy_streak(self):
        """Gets the best_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The best_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._best_healthy_streak

    @best_healthy_streak.setter
    def best_healthy_streak(self, best_healthy_streak):
        """Sets the best_healthy_streak of this DomainMonitorInsightsDto.


        :param best_healthy_streak: The best_healthy_streak of this DomainMonitorInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and best_healthy_streak is None:  # noqa: E501
            raise ValueError("Invalid value for `best_healthy_streak`, must not be `None`")  # noqa: E501

        self._best_healthy_streak = best_healthy_streak

    @property
    def good_performance_signals(self):
        """Gets the good_performance_signals of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The good_performance_signals of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._good_performance_signals

    @good_performance_signals.setter
    def good_performance_signals(self, good_performance_signals):
        """Sets the good_performance_signals of this DomainMonitorInsightsDto.


        :param good_performance_signals: The good_performance_signals of this DomainMonitorInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and good_performance_signals is None:  # noqa: E501
            raise ValueError("Invalid value for `good_performance_signals`, must not be `None`")  # noqa: E501

        self._good_performance_signals = good_performance_signals

    @property
    def attention_signals(self):
        """Gets the attention_signals of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The attention_signals of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._attention_signals

    @attention_signals.setter
    def attention_signals(self, attention_signals):
        """Sets the attention_signals of this DomainMonitorInsightsDto.


        :param attention_signals: The attention_signals of this DomainMonitorInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and attention_signals is None:  # noqa: E501
            raise ValueError("Invalid value for `attention_signals`, must not be `None`")  # noqa: E501

        self._attention_signals = attention_signals

    @property
    def top_findings(self):
        """Gets the top_findings of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The top_findings of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._top_findings

    @top_findings.setter
    def top_findings(self, top_findings):
        """Sets the top_findings of this DomainMonitorInsightsDto.


        :param top_findings: The top_findings of this DomainMonitorInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and top_findings is None:  # noqa: E501
            raise ValueError("Invalid value for `top_findings`, must not be `None`")  # noqa: E501

        self._top_findings = top_findings

    @property
    def latest_run(self):
        """Gets the latest_run of this DomainMonitorInsightsDto.  # noqa: E501


        :return: The latest_run of this DomainMonitorInsightsDto.  # noqa: E501
        :rtype: DomainMonitorRunDto
        """
        return self._latest_run

    @latest_run.setter
    def latest_run(self, latest_run):
        """Sets the latest_run of this DomainMonitorInsightsDto.


        :param latest_run: The latest_run of this DomainMonitorInsightsDto.  # noqa: E501
        :type: DomainMonitorRunDto
        """

        self._latest_run = latest_run

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorInsightsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorInsightsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.webhook_controller_api import WebhookControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestWebhookControllerApi(unittest.TestCase):
    """WebhookControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.webhook_controller_api.WebhookControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_account_webhook(self):
        """Test case for create_account_webhook

        Attach a WebHook URL to an inbox  # noqa: E501
        """
        pass

    def test_create_webhook(self):
        """Test case for create_webhook

        Attach a WebHook URL to an inbox  # noqa: E501
        """
        pass

    def test_create_webhook_for_ai_transformer(self):
        """Test case for create_webhook_for_ai_transformer

        Attach a WebHook URL to an AI transformer  # noqa: E501
        """
        pass

    def test_create_webhook_for_phone_number(self):
        """Test case for create_webhook_for_phone_number

        Attach a WebHook URL to a phone number  # noqa: E501
        """
        pass

    def test_delete_all_webhooks(self):
        """Test case for delete_all_webhooks

        Delete all webhooks  # noqa: E501
        """
        pass

    def test_delete_webhook(self):
        """Test case for delete_webhook

        Delete and disable a Webhook for an Inbox  # noqa: E501
        """
        pass

    def test_delete_webhook_by_id(self):
        """Test case for delete_webhook_by_id

        Delete a webhook  # noqa: E501
        """
        pass

    def test_get_all_account_webhooks(self):
        """Test case for get_all_account_webhooks

        List account webhooks Paginated  # noqa: E501
        """
        pass

    def test_get_all_webhook_endpoints(self):
        """Test case for get_all_webhook_endpoints

        List Webhooks endpoints Paginated  # noqa: E501
        """
        pass

    def test_get_all_webhook_results(self):
        """Test case for get_all_webhook_results

        Get results for all webhooks  # noqa: E501
        """
        pass

    def test_get_all_webhooks(self):
        """Test case for get_all_webhooks

        List Webhooks Paginated  # noqa: E501
        """
        pass

    def test_get_inbox_webhooks_paginated(self):
        """Test case for get_inbox_webhooks_paginated

        Get paginated webhooks for an Inbox  # noqa: E501
        """
        pass

    def test_get_json_schema_for_webhook_event(self):
        """Test case for get_json_schema_for_webhook_event

        """
        pass

    def test_get_json_schema_for_webhook_payload(self):
        """Test case for get_json_schema_for_webhook_payload

        """
        pass

    def test_get_phone_number_webhooks_paginated(self):
        """Test case for get_phone_number_webhooks_paginated

        Get paginated webhooks for a phone number  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload(self):
        """Test case for get_test_webhook_payload

        """
        pass

    def test_get_test_webhook_payload_bounce(self):
        """Test case for get_test_webhook_payload_bounce

        """
        pass

    def test_get_test_webhook_payload_bounce_recipient(self):
        """Test case for get_test_webhook_payload_bounce_recipient

        """
        pass

    def test_get_test_webhook_payload_delivery_status(self):
        """Test case for get_test_webhook_payload_delivery_status

        Get webhook test payload for delivery status event  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload_email_opened(self):
        """Test case for get_test_webhook_payload_email_opened

        """
        pass

    def test_get_test_webhook_payload_email_read(self):
        """Test case for get_test_webhook_payload_email_read

        """
        pass

    def test_get_test_webhook_payload_for_webhook(self):
        """Test case for get_test_webhook_payload_for_webhook

        """
        pass

    def test_get_test_webhook_payload_new_ai_transform_result(self):
        """Test case for get_test_webhook_payload_new_ai_transform_result

        Get webhook test payload for new ai transform result event  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload_new_attachment(self):
        """Test case for get_test_webhook_payload_new_attachment

        Get webhook test payload for new attachment event  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload_new_contact(self):
        """Test case for get_test_webhook_payload_new_contact

        Get webhook test payload for new contact event  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload_new_email(self):
        """Test case for get_test_webhook_payload_new_email

        Get webhook test payload for new email event  # noqa: E501
        """
        pass

    def test_get_test_webhook_payload_new_sms(self):
        """Test case for get_test_webhook_payload_new_sms

        Get webhook test payload for new sms event  # noqa: E501
        """
        pass

    def test_get_webhook(self):
        """Test case for get_webhook

        Get a webhook  # noqa: E501
        """
        pass

    def test_get_webhook_result(self):
        """Test case for get_webhook_result

        Get a webhook result for a webhook  # noqa: E501
        """
        pass

    def test_get_webhook_results(self):
        """Test case for get_webhook_results

        Get a webhook results for a webhook  # noqa: E501
        """
        pass

    def test_get_webhook_results_count(self):
        """Test case for get_webhook_results_count

        Get a webhook results count for a webhook  # noqa: E501
        """
        pass

    def test_get_webhook_results_unseen_error_count(self):
        """Test case for get_webhook_results_unseen_error_count

        Get count of unseen webhook results with error status  # noqa: E501
        """
        pass

    def test_get_webhooks(self):
        """Test case for get_webhooks

        Get all webhooks for an Inbox  # noqa: E501
        """
        pass

    def test_redrive_all_webhook_results(self):
        """Test case for redrive_all_webhook_results

        Redrive all webhook results that have failed status  # noqa: E501
        """
        pass

    def test_redrive_webhook_result(self):
        """Test case for redrive_webhook_result

        Get a webhook result and try to resend the original webhook payload  # noqa: E501
        """
        pass

    def test_send_test_data(self):
        """Test case for send_test_data

        Send webhook test data  # noqa: E501
        """
        pass

    def test_update_webhook(self):
        """Test case for update_webhook

        Update a webhook  # noqa: E501
        """
        pass

    def test_update_webhook_headers(self):
        """Test case for update_webhook_headers

        Update a webhook request headers  # noqa: E501
        """
        pass

    def test_verify_webhook_signature(self):
        """Test case for verify_webhook_signature

        Verify a webhook payload signature  # noqa: E501
        """
        pass

    def test_wait_for_webhook_results(self):
        """Test case for wait_for_webhook_results

        Wait for webhook results for a webhook  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.user_controller_api import UserControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestUserControllerApi(unittest.TestCase):
    """UserControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.user_controller_api.UserControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_or_update_inbox_retention_policy_for_account(self):
        """Test case for create_or_update_inbox_retention_policy_for_account

        """
        pass

    def test_delete_inbox_retention_policy_for_account(self):
        """Test case for delete_inbox_retention_policy_for_account

        """
        pass

    def test_get_entity_automations(self):
        """Test case for get_entity_automations

        """
        pass

    def test_get_entity_events(self):
        """Test case for get_entity_events

        """
        pass

    def test_get_entity_favorites(self):
        """Test case for get_entity_favorites

        """
        pass

    def test_get_inbox_retention_policy_for_account(self):
        """Test case for get_inbox_retention_policy_for_account

        """
        pass

    def test_get_json_property_as_string(self):
        """Test case for get_json_property_as_string

        """
        pass

    def test_get_user_info(self):
        """Test case for get_user_info

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceTestsOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'check_random_local_part': 'bool',
        'check_free_provider': 'bool',
        'check_https_website': 'bool',
        'check_dns': 'bool',
        'check_domain_age_hint': 'bool'
    }

    attribute_map = {
        'check_random_local_part': 'checkRandomLocalPart',
        'check_free_provider': 'checkFreeProvider',
        'check_https_website': 'checkHttpsWebsite',
        'check_dns': 'checkDns',
        'check_domain_age_hint': 'checkDomainAgeHint'
    }

    def __init__(self, check_random_local_part=None, check_free_provider=None, check_https_website=None, check_dns=None, check_domain_age_hint=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceTestsOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._check_random_local_part = None
        self._check_free_provider = None
        self._check_https_website = None
        self._check_dns = None
        self._check_domain_age_hint = None
        self.discriminator = None

        self.check_random_local_part = check_random_local_part
        self.check_free_provider = check_free_provider
        self.check_https_website = check_https_website
        self.check_dns = check_dns
        self.check_domain_age_hint = check_domain_age_hint

    @property
    def check_random_local_part(self):
        """Gets the check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check local-part randomness for email inputs.  # noqa: E501

        :return: The check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_random_local_part

    @check_random_local_part.setter
    def check_random_local_part(self, check_random_local_part):
        """Sets the check_random_local_part of this EmailIntelligenceTestsOptions.

        Check local-part randomness for email inputs.  # noqa: E501

        :param check_random_local_part: The check_random_local_part of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_random_local_part = check_random_local_part

    @property
    def check_free_provider(self):
        """Gets the check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check if domain is a known free email provider.  # noqa: E501

        :return: The check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_free_provider

    @check_free_provider.setter
    def check_free_provider(self, check_free_provider):
        """Sets the check_free_provider of this EmailIntelligenceTestsOptions.

        Check if domain is a known free email provider.  # noqa: E501

        :param check_free_provider: The check_free_provider of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_free_provider = check_free_provider

    @property
    def check_https_website(self):
        """Gets the check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check if the domain has a reachable HTTPS website.  # noqa: E501

        :return: The check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_https_website

    @check_https_website.setter
    def check_https_website(self, check_https_website):
        """Sets the check_https_website of this EmailIntelligenceTestsOptions.

        Check if the domain has a reachable HTTPS website.  # noqa: E501

        :param check_https_website: The check_https_website of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_https_website = check_https_website

    @property
    def check_dns(self):
        """Gets the check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501

        Check DNS records (A, MX, SOA) for the domain.  # noqa: E501

        :return: The check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_dns

    @check_dns.setter
    def check_dns(self, check_dns):
        """Sets the check_dns of this EmailIntelligenceTestsOptions.

        Check DNS records (A, MX, SOA) for the domain.  # noqa: E501

        :param check_dns: The check_dns of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_dns = check_dns

    @property
    def check_domain_age_hint(self):
        """Gets the check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501

        Derive a domain age hint from DNS SOA serial when possible.  # noqa: E501

        :return: The check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._check_domain_age_hint

    @check_domain_age_hint.setter
    def check_domain_age_hint(self, check_domain_age_hint):
        """Sets the check_domain_age_hint of this EmailIntelligenceTestsOptions.

        Derive a domain age hint from DNS SOA serial when possible.  # noqa: E501

        :param check_domain_age_hint: The check_domain_age_hint of this EmailIntelligenceTestsOptions.  # noqa: E501
        :type: bool
        """

        self._check_domain_age_hint = check_domain_age_hint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceTestsOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceTestsOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckDnsPropagationResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'record_type': 'str',
        'expected_value': 'str',
        'propagated_to_all_resolvers': 'bool',
        'responding_resolver_count': 'int',
        'matching_resolver_count': 'int',
        'resolver_results': 'list[DnsPropagationResolverResult]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'host': 'host',
        'record_type': 'recordType',
        'expected_value': 'expectedValue',
        'propagated_to_all_resolvers': 'propagatedToAllResolvers',
        'responding_resolver_count': 'respondingResolverCount',
        'matching_resolver_count': 'matchingResolverCount',
        'resolver_results': 'resolverResults',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, host=None, record_type=None, expected_value=None, propagated_to_all_resolvers=None, responding_resolver_count=None, matching_resolver_count=None, resolver_results=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """CheckDnsPropagationResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._record_type = None
        self._expected_value = None
        self._propagated_to_all_resolvers = None
        self._responding_resolver_count = None
        self._matching_resolver_count = None
        self._resolver_results = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.host = host
        self.record_type = record_type
        self.expected_value = expected_value
        self.propagated_to_all_resolvers = propagated_to_all_resolvers
        self.responding_resolver_count = responding_resolver_count
        self.matching_resolver_count = matching_resolver_count
        self.resolver_results = resolver_results
        self.warnings = warnings
        self.errors = errors

    @property
    def host(self):
        """Gets the host of this CheckDnsPropagationResults.  # noqa: E501


        :return: The host of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this CheckDnsPropagationResults.


        :param host: The host of this CheckDnsPropagationResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def record_type(self):
        """Gets the record_type of this CheckDnsPropagationResults.  # noqa: E501

        Domain Name Server Record Types  # noqa: E501

        :return: The record_type of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: str
        """
        return self._record_type

    @record_type.setter
    def record_type(self, record_type):
        """Sets the record_type of this CheckDnsPropagationResults.

        Domain Name Server Record Types  # noqa: E501

        :param record_type: The record_type of this CheckDnsPropagationResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and record_type is None:  # noqa: E501
            raise ValueError("Invalid value for `record_type`, must not be `None`")  # noqa: E501
        allowed_values = ["A", "NS", "MD", "MF", "CNAME", "SOA", "MB", "MG", "MR", "NULL", "WKS", "PTR", "HINFO", "MINFO", "MX", "TXT", "RP", "AFSDB", "X25", "ISDN", "RT", "NSAP", "NSAP_PTR", "SIG", "KEY", "PX", "GPOS", "AAAA", "LOC", "NXT", "EID", "NIMLOC", "SRV", "ATMA", "NAPTR", "KX", "CERT", "A6", "DNAME", "SINK", "OPT", "APL", "DS", "SSHFP", "IPSECKEY", "RRSIG", "NSEC", "DNSKEY", "DHCID", "NSEC3", "NSEC3PARAM", "TLSA", "SMIMEA", "HIP", "NINFO", "RKEY", "TALINK", "CDS", "CDNSKEY", "OPENPGPKEY", "CSYNC", "ZONEMD", "SVCB", "HTTPS", "SPF", "UINFO", "UID", "GID", "UNSPEC", "NID", "L32", "L64", "LP", "EUI48", "EUI64", "TKEY", "TSIG", "IXFR", "AXFR", "MAILB", "MAILA", "ANY", "URI", "CAA", "AVC", "DOA", "AMTRELAY", "TA", "DLV"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and record_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `record_type` ({0}), must be one of {1}"  # noqa: E501
                .format(record_type, allowed_values)
            )

        self._record_type = record_type

    @property
    def expected_value(self):
        """Gets the expected_value of this CheckDnsPropagationResults.  # noqa: E501


        :return: The expected_value of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: str
        """
        return self._expected_value

    @expected_value.setter
    def expected_value(self, expected_value):
        """Sets the expected_value of this CheckDnsPropagationResults.


        :param expected_value: The expected_value of this CheckDnsPropagationResults.  # noqa: E501
        :type: str
        """

        self._expected_value = expected_value

    @property
    def propagated_to_all_resolvers(self):
        """Gets the propagated_to_all_resolvers of this CheckDnsPropagationResults.  # noqa: E501


        :return: The propagated_to_all_resolvers of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: bool
        """
        return self._propagated_to_all_resolvers

    @propagated_to_all_resolvers.setter
    def propagated_to_all_resolvers(self, propagated_to_all_resolvers):
        """Sets the propagated_to_all_resolvers of this CheckDnsPropagationResults.


        :param propagated_to_all_resolvers: The propagated_to_all_resolvers of this CheckDnsPropagationResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and propagated_to_all_resolvers is None:  # noqa: E501
            raise ValueError("Invalid value for `propagated_to_all_resolvers`, must not be `None`")  # noqa: E501

        self._propagated_to_all_resolvers = propagated_to_all_resolvers

    @property
    def responding_resolver_count(self):
        """Gets the responding_resolver_count of this CheckDnsPropagationResults.  # noqa: E501


        :return: The responding_resolver_count of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: int
        """
        return self._responding_resolver_count

    @responding_resolver_count.setter
    def responding_resolver_count(self, responding_resolver_count):
        """Sets the responding_resolver_count of this CheckDnsPropagationResults.


        :param responding_resolver_count: The responding_resolver_count of this CheckDnsPropagationResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and responding_resolver_count is None:  # noqa: E501
            raise ValueError("Invalid value for `responding_resolver_count`, must not be `None`")  # noqa: E501

        self._responding_resolver_count = responding_resolver_count

    @property
    def matching_resolver_count(self):
        """Gets the matching_resolver_count of this CheckDnsPropagationResults.  # noqa: E501


        :return: The matching_resolver_count of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: int
        """
        return self._matching_resolver_count

    @matching_resolver_count.setter
    def matching_resolver_count(self, matching_resolver_count):
        """Sets the matching_resolver_count of this CheckDnsPropagationResults.


        :param matching_resolver_count: The matching_resolver_count of this CheckDnsPropagationResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and matching_resolver_count is None:  # noqa: E501
            raise ValueError("Invalid value for `matching_resolver_count`, must not be `None`")  # noqa: E501

        self._matching_resolver_count = matching_resolver_count

    @property
    def resolver_results(self):
        """Gets the resolver_results of this CheckDnsPropagationResults.  # noqa: E501


        :return: The resolver_results of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: list[DnsPropagationResolverResult]
        """
        return self._resolver_results

    @resolver_results.setter
    def resolver_results(self, resolver_results):
        """Sets the resolver_results of this CheckDnsPropagationResults.


        :param resolver_results: The resolver_results of this CheckDnsPropagationResults.  # noqa: E501
        :type: list[DnsPropagationResolverResult]
        """
        if self.local_vars_configuration.client_side_validation and resolver_results is None:  # noqa: E501
            raise ValueError("Invalid value for `resolver_results`, must not be `None`")  # noqa: E501

        self._resolver_results = resolver_results

    @property
    def warnings(self):
        """Gets the warnings of this CheckDnsPropagationResults.  # noqa: E501


        :return: The warnings of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this CheckDnsPropagationResults.


        :param warnings: The warnings of this CheckDnsPropagationResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this CheckDnsPropagationResults.  # noqa: E501


        :return: The errors of this CheckDnsPropagationResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this CheckDnsPropagationResults.


        :param errors: The errors of this CheckDnsPropagationResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckDnsPropagationResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckDnsPropagationResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.inbox_replier_controller_api import InboxReplierControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestInboxReplierControllerApi(unittest.TestCase):
    """InboxReplierControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.inbox_replier_controller_api.InboxReplierControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_inbox_replier(self):
        """Test case for create_new_inbox_replier

        Create an inbox replier  # noqa: E501
        """
        pass

    def test_delete_inbox_replier(self):
        """Test case for delete_inbox_replier

        Delete an inbox replier  # noqa: E501
        """
        pass

    def test_delete_inbox_repliers(self):
        """Test case for delete_inbox_repliers

        Delete inbox repliers  # noqa: E501
        """
        pass

    def test_get_all_inbox_replier_events(self):
        """Test case for get_all_inbox_replier_events

        Get inbox replier event list  # noqa: E501
        """
        pass

    def test_get_inbox_replier(self):
        """Test case for get_inbox_replier

        Get an inbox replier  # noqa: E501
        """
        pass

    def test_get_inbox_replier_events(self):
        """Test case for get_inbox_replier_events

        Get an inbox replier event list  # noqa: E501
        """
        pass

    def test_get_inbox_repliers(self):
        """Test case for get_inbox_repliers

        List inbox repliers  # noqa: E501
        """
        pass

    def test_update_inbox_replier(self):
        """Test case for update_inbox_replier

        Update an inbox replier  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UserControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_or_update_inbox_retention_policy_for_account(self, create_inbox_retention_policy_for_account_options, **kwargs):  # noqa: E501
        """create_or_update_inbox_retention_policy_for_account  # noqa: E501

        Create inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_inbox_retention_policy_for_account(create_inbox_retention_policy_for_account_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateInboxRetentionPolicyForAccountOptions create_inbox_retention_policy_for_account_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InboxRetentionPolicyDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_or_update_inbox_retention_policy_for_account_with_http_info(create_inbox_retention_policy_for_account_options, **kwargs)  # noqa: E501

    def create_or_update_inbox_retention_policy_for_account_with_http_info(self, create_inbox_retention_policy_for_account_options, **kwargs):  # noqa: E501
        """create_or_update_inbox_retention_policy_for_account  # noqa: E501

        Create inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_inbox_retention_policy_for_account_with_http_info(create_inbox_retention_policy_for_account_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateInboxRetentionPolicyForAccountOptions create_inbox_retention_policy_for_account_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InboxRetentionPolicyDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_inbox_retention_policy_for_account_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_or_update_inbox_retention_policy_for_account" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_inbox_retention_policy_for_account_options' is set
        if self.api_client.client_side_validation and ('create_inbox_retention_policy_for_account_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_inbox_retention_policy_for_account_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_inbox_retention_policy_for_account_options` when calling `create_or_update_inbox_retention_policy_for_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_inbox_retention_policy_for_account_options' in local_var_params:
            body_params = local_var_params['create_inbox_retention_policy_for_account_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/inbox-retention-policies/account', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InboxRetentionPolicyDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_inbox_retention_policy_for_account(self, **kwargs):  # noqa: E501
        """delete_inbox_retention_policy_for_account  # noqa: E501

        Delete inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_retention_policy_for_account(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: EmptyResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_inbox_retention_policy_for_account_with_http_info(**kwargs)  # noqa: E501

    def delete_inbox_retention_policy_for_account_with_http_info(self, **kwargs):  # noqa: E501
        """delete_inbox_retention_policy_for_account  # noqa: E501

        Delete inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_retention_policy_for_account_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(EmptyResponseDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_inbox_retention_policy_for_account" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/inbox-retention-policies/account', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_entity_automations(self, **kwargs):  # noqa: E501
        """get_entity_automations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_automations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str inbox_id: Optional inbox ID
        :param str phone_id: Optional phone ID
        :param str filter: Optional automation type filter
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageEntityAutomationItems
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_entity_automations_with_http_info(**kwargs)  # noqa: E501

    def get_entity_automations_with_http_info(self, **kwargs):  # noqa: E501
        """get_entity_automations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_automations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str inbox_id: Optional inbox ID
        :param str phone_id: Optional phone ID
        :param str filter: Optional automation type filter
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageEntityAutomationItems, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'page',
            'size',
            'sort',
            'since',
            'before',
            'inbox_id',
            'phone_id',
            'filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entity_automations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_entity_automations`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501
        if 'phone_id' in local_var_params and local_var_params['phone_id'] is not None:  # noqa: E501
            query_params.append(('phoneId', local_var_params['phone_id']))  # noqa: E501
        if 'filter' in local_var_params and local_var_params['filter'] is not None:  # noqa: E501
            query_params.append(('filter', local_var_params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/automations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageEntityAutomationItems',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_entity_events(self, **kwargs):  # noqa: E501
        """get_entity_events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str inbox_id: Optional inbox ID
        :param str email_id: Optional email ID
        :param str phone_id: Optional phone ID
        :param str sms_id: Optional SMS ID
        :param str attachment_id: Optional attachment ID
        :param str filter: Optional type filter
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageEntityEventItems
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_entity_events_with_http_info(**kwargs)  # noqa: E501

    def get_entity_events_with_http_info(self, **kwargs):  # noqa: E501
        """get_entity_events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str inbox_id: Optional inbox ID
        :param str email_id: Optional email ID
        :param str phone_id: Optional phone ID
        :param str sms_id: Optional SMS ID
        :param str attachment_id: Optional attachment ID
        :param str filter: Optional type filter
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageEntityEventItems, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'page',
            'size',
            'sort',
            'since',
            'before',
            'inbox_id',
            'email_id',
            'phone_id',
            'sms_id',
            'attachment_id',
            'filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entity_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_entity_events`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501
        if 'email_id' in local_var_params and local_var_params['email_id'] is not None:  # noqa: E501
            query_params.append(('emailId', local_var_params['email_id']))  # noqa: E501
        if 'phone_id' in local_var_params and local_var_params['phone_id'] is not None:  # noqa: E501
            query_params.append(('phoneId', local_var_params['phone_id']))  # noqa: E501
        if 'sms_id' in local_var_params and local_var_params['sms_id'] is not None:  # noqa: E501
            query_params.append(('smsId', local_var_params['sms_id']))  # noqa: E501
        if 'attachment_id' in local_var_params and local_var_params['attachment_id'] is not None:  # noqa: E501
            query_params.append(('attachmentId', local_var_params['attachment_id']))  # noqa: E501
        if 'filter' in local_var_params and local_var_params['filter'] is not None:  # noqa: E501
            query_params.append(('filter', local_var_params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageEntityEventItems',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_entity_favorites(self, **kwargs):  # noqa: E501
        """get_entity_favorites  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_favorites(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str filter: Optional type filter
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageEntityFavouriteItems
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_entity_favorites_with_http_info(**kwargs)  # noqa: E501

    def get_entity_favorites_with_http_info(self, **kwargs):  # noqa: E501
        """get_entity_favorites  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_favorites_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page: Optional page index
        :param int size: Optional page size
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param str filter: Optional type filter
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageEntityFavouriteItems, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'page',
            'size',
            'sort',
            'since',
            'before',
            'filter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entity_favorites" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_entity_favorites`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'filter' in local_var_params and local_var_params['filter'] is not None:  # noqa: E501
            query_params.append(('filter', local_var_params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/favorites', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageEntityFavouriteItems',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_inbox_retention_policy_for_account(self, **kwargs):  # noqa: E501
        """get_inbox_retention_policy_for_account  # noqa: E501

        Get inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_retention_policy_for_account(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InboxRetentionPolicyOptionalDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_inbox_retention_policy_for_account_with_http_info(**kwargs)  # noqa: E501

    def get_inbox_retention_policy_for_account_with_http_info(self, **kwargs):  # noqa: E501
        """get_inbox_retention_policy_for_account  # noqa: E501

        Get inbox retention policy for your global account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_retention_policy_for_account_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InboxRetentionPolicyOptionalDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_inbox_retention_policy_for_account" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/inbox-retention-policies/account', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InboxRetentionPolicyOptionalDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_json_property_as_string(self, _property, body, **kwargs):  # noqa: E501
        """get_json_property_as_string  # noqa: E501

        Utility function to extract properties from JSON objects in language where this is cumbersome.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_json_property_as_string(_property, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _property: JSON property name or dot separated path selector such as `a.b.c` (required)
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_json_property_as_string_with_http_info(_property, body, **kwargs)  # noqa: E501

    def get_json_property_as_string_with_http_info(self, _property, body, **kwargs):  # noqa: E501
        """get_json_property_as_string  # noqa: E501

        Utility function to extract properties from JSON objects in language where this is cumbersome.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_json_property_as_string_with_http_info(_property, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str _property: JSON property name or dot separated path selector such as `a.b.c` (required)
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            '_property',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_json_property_as_string" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter '_property' is set
        if self.api_client.client_side_validation and ('_property' not in local_var_params or  # noqa: E501
                                                        local_var_params['_property'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `_property` when calling `get_json_property_as_string`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_property' in local_var_params and local_var_params['_property'] is not None:  # noqa: E501
            query_params.append(('property', local_var_params['_property']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/json/pluck', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_info(self, **kwargs):  # noqa: E501
        """get_user_info  # noqa: E501

        Get account information for your user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserInfoDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_info_with_http_info(**kwargs)  # noqa: E501

    def get_user_info_with_http_info(self, **kwargs):  # noqa: E501
        """get_user_info  # noqa: E501

        Get account information for your user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserInfoDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/user/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserInfoDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateConnectorSmtpConnectionOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'smtp_host': 'str',
        'smtp_port': 'int',
        'smtp_ssl': 'bool',
        'smtp_username': 'str',
        'smtp_password': 'str',
        'smtp_mechanisms': 'list[str]',
        'start_tls': 'bool',
        'local_host_name': 'str',
        'proxy_host': 'str',
        'proxy_port': 'int',
        'proxy_enabled': 'bool',
        'ssl_trust': 'str',
        'ssl_protocols': 'list[str]'
    }

    attribute_map = {
        'enabled': 'enabled',
        'smtp_host': 'smtpHost',
        'smtp_port': 'smtpPort',
        'smtp_ssl': 'smtpSsl',
        'smtp_username': 'smtpUsername',
        'smtp_password': 'smtpPassword',
        'smtp_mechanisms': 'smtpMechanisms',
        'start_tls': 'startTls',
        'local_host_name': 'localHostName',
        'proxy_host': 'proxyHost',
        'proxy_port': 'proxyPort',
        'proxy_enabled': 'proxyEnabled',
        'ssl_trust': 'sslTrust',
        'ssl_protocols': 'sslProtocols'
    }

    def __init__(self, enabled=None, smtp_host=None, smtp_port=None, smtp_ssl=None, smtp_username=None, smtp_password=None, smtp_mechanisms=None, start_tls=None, local_host_name=None, proxy_host=None, proxy_port=None, proxy_enabled=None, ssl_trust=None, ssl_protocols=None, local_vars_configuration=None):  # noqa: E501
        """CreateConnectorSmtpConnectionOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._smtp_host = None
        self._smtp_port = None
        self._smtp_ssl = None
        self._smtp_username = None
        self._smtp_password = None
        self._smtp_mechanisms = None
        self._start_tls = None
        self._local_host_name = None
        self._proxy_host = None
        self._proxy_port = None
        self._proxy_enabled = None
        self._ssl_trust = None
        self._ssl_protocols = None
        self.discriminator = None

        self.enabled = enabled
        self.smtp_host = smtp_host
        self.smtp_port = smtp_port
        self.smtp_ssl = smtp_ssl
        self.smtp_username = smtp_username
        self.smtp_password = smtp_password
        self.smtp_mechanisms = smtp_mechanisms
        self.start_tls = start_tls
        self.local_host_name = local_host_name
        self.proxy_host = proxy_host
        self.proxy_port = proxy_port
        self.proxy_enabled = proxy_enabled
        self.ssl_trust = ssl_trust
        self.ssl_protocols = ssl_protocols

    @property
    def enabled(self):
        """Gets the enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateConnectorSmtpConnectionOptions.


        :param enabled: The enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def smtp_host(self):
        """Gets the smtp_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._smtp_host

    @smtp_host.setter
    def smtp_host(self, smtp_host):
        """Sets the smtp_host of this CreateConnectorSmtpConnectionOptions.


        :param smtp_host: The smtp_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and smtp_host is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_host`, must not be `None`")  # noqa: E501

        self._smtp_host = smtp_host

    @property
    def smtp_port(self):
        """Gets the smtp_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: int
        """
        return self._smtp_port

    @smtp_port.setter
    def smtp_port(self, smtp_port):
        """Sets the smtp_port of this CreateConnectorSmtpConnectionOptions.


        :param smtp_port: The smtp_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: int
        """

        self._smtp_port = smtp_port

    @property
    def smtp_ssl(self):
        """Gets the smtp_ssl of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_ssl of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._smtp_ssl

    @smtp_ssl.setter
    def smtp_ssl(self, smtp_ssl):
        """Sets the smtp_ssl of this CreateConnectorSmtpConnectionOptions.


        :param smtp_ssl: The smtp_ssl of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._smtp_ssl = smtp_ssl

    @property
    def smtp_username(self):
        """Gets the smtp_username of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_username of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._smtp_username

    @smtp_username.setter
    def smtp_username(self, smtp_username):
        """Sets the smtp_username of this CreateConnectorSmtpConnectionOptions.


        :param smtp_username: The smtp_username of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """

        self._smtp_username = smtp_username

    @property
    def smtp_password(self):
        """Gets the smtp_password of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_password of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._smtp_password

    @smtp_password.setter
    def smtp_password(self, smtp_password):
        """Sets the smtp_password of this CreateConnectorSmtpConnectionOptions.


        :param smtp_password: The smtp_password of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """

        self._smtp_password = smtp_password

    @property
    def smtp_mechanisms(self):
        """Gets the smtp_mechanisms of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The smtp_mechanisms of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._smtp_mechanisms

    @smtp_mechanisms.setter
    def smtp_mechanisms(self, smtp_mechanisms):
        """Sets the smtp_mechanisms of this CreateConnectorSmtpConnectionOptions.


        :param smtp_mechanisms: The smtp_mechanisms of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: list[str]
        """

        self._smtp_mechanisms = smtp_mechanisms

    @property
    def start_tls(self):
        """Gets the start_tls of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The start_tls of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._start_tls

    @start_tls.setter
    def start_tls(self, start_tls):
        """Sets the start_tls of this CreateConnectorSmtpConnectionOptions.


        :param start_tls: The start_tls of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._start_tls = start_tls

    @property
    def local_host_name(self):
        """Gets the local_host_name of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The local_host_name of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._local_host_name

    @local_host_name.setter
    def local_host_name(self, local_host_name):
        """Sets the local_host_name of this CreateConnectorSmtpConnectionOptions.


        :param local_host_name: The local_host_name of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """

        self._local_host_name = local_host_name

    @property
    def proxy_host(self):
        """Gets the proxy_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The proxy_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._proxy_host

    @proxy_host.setter
    def proxy_host(self, proxy_host):
        """Sets the proxy_host of this CreateConnectorSmtpConnectionOptions.


        :param proxy_host: The proxy_host of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """

        self._proxy_host = proxy_host

    @property
    def proxy_port(self):
        """Gets the proxy_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The proxy_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: int
        """
        return self._proxy_port

    @proxy_port.setter
    def proxy_port(self, proxy_port):
        """Sets the proxy_port of this CreateConnectorSmtpConnectionOptions.


        :param proxy_port: The proxy_port of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: int
        """

        self._proxy_port = proxy_port

    @property
    def proxy_enabled(self):
        """Gets the proxy_enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The proxy_enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._proxy_enabled

    @proxy_enabled.setter
    def proxy_enabled(self, proxy_enabled):
        """Sets the proxy_enabled of this CreateConnectorSmtpConnectionOptions.


        :param proxy_enabled: The proxy_enabled of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._proxy_enabled = proxy_enabled

    @property
    def ssl_trust(self):
        """Gets the ssl_trust of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The ssl_trust of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._ssl_trust

    @ssl_trust.setter
    def ssl_trust(self, ssl_trust):
        """Sets the ssl_trust of this CreateConnectorSmtpConnectionOptions.


        :param ssl_trust: The ssl_trust of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: str
        """

        self._ssl_trust = ssl_trust

    @property
    def ssl_protocols(self):
        """Gets the ssl_protocols of this CreateConnectorSmtpConnectionOptions.  # noqa: E501


        :return: The ssl_protocols of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ssl_protocols

    @ssl_protocols.setter
    def ssl_protocols(self, ssl_protocols):
        """Sets the ssl_protocols of this CreateConnectorSmtpConnectionOptions.


        :param ssl_protocols: The ssl_protocols of this CreateConnectorSmtpConnectionOptions.  # noqa: E501
        :type: list[str]
        """

        self._ssl_protocols = ssl_protocols

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorSmtpConnectionOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConnectorSmtpConnectionOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewTargetDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'run_id': 'str',
        'provider': 'str',
        'client_profile': 'str',
        'device_type': 'str',
        'browser_family': 'str',
        'platform': 'str',
        'color_scheme': 'str',
        'status': 'str',
        'failure_code': 'str',
        'primary_screenshot_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'run_id': 'runId',
        'provider': 'provider',
        'client_profile': 'clientProfile',
        'device_type': 'deviceType',
        'browser_family': 'browserFamily',
        'platform': 'platform',
        'color_scheme': 'colorScheme',
        'status': 'status',
        'failure_code': 'failureCode',
        'primary_screenshot_id': 'primaryScreenshotId',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, run_id=None, provider=None, client_profile=None, device_type=None, browser_family=None, platform=None, color_scheme=None, status=None, failure_code=None, primary_screenshot_id=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewTargetDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._run_id = None
        self._provider = None
        self._client_profile = None
        self._device_type = None
        self._browser_family = None
        self._platform = None
        self._color_scheme = None
        self._status = None
        self._failure_code = None
        self._primary_screenshot_id = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.run_id = run_id
        if provider is not None:
            self.provider = provider
        if client_profile is not None:
            self.client_profile = client_profile
        if device_type is not None:
            self.device_type = device_type
        if browser_family is not None:
            self.browser_family = browser_family
        if platform is not None:
            self.platform = platform
        if color_scheme is not None:
            self.color_scheme = color_scheme
        if status is not None:
            self.status = status
        if failure_code is not None:
            self.failure_code = failure_code
        if primary_screenshot_id is not None:
            self.primary_screenshot_id = primary_screenshot_id
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DevicePreviewTargetDto.


        :param id: The id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def run_id(self):
        """Gets the run_id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The run_id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this DevicePreviewTargetDto.


        :param run_id: The run_id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and run_id is None:  # noqa: E501
            raise ValueError("Invalid value for `run_id`, must not be `None`")  # noqa: E501

        self._run_id = run_id

    @property
    def provider(self):
        """Gets the provider of this DevicePreviewTargetDto.  # noqa: E501


        :return: The provider of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this DevicePreviewTargetDto.


        :param provider: The provider of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def client_profile(self):
        """Gets the client_profile of this DevicePreviewTargetDto.  # noqa: E501


        :return: The client_profile of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._client_profile

    @client_profile.setter
    def client_profile(self, client_profile):
        """Sets the client_profile of this DevicePreviewTargetDto.


        :param client_profile: The client_profile of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._client_profile = client_profile

    @property
    def device_type(self):
        """Gets the device_type of this DevicePreviewTargetDto.  # noqa: E501


        :return: The device_type of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this DevicePreviewTargetDto.


        :param device_type: The device_type of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def browser_family(self):
        """Gets the browser_family of this DevicePreviewTargetDto.  # noqa: E501


        :return: The browser_family of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._browser_family

    @browser_family.setter
    def browser_family(self, browser_family):
        """Sets the browser_family of this DevicePreviewTargetDto.


        :param browser_family: The browser_family of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._browser_family = browser_family

    @property
    def platform(self):
        """Gets the platform of this DevicePreviewTargetDto.  # noqa: E501


        :return: The platform of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this DevicePreviewTargetDto.


        :param platform: The platform of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def color_scheme(self):
        """Gets the color_scheme of this DevicePreviewTargetDto.  # noqa: E501


        :return: The color_scheme of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._color_scheme

    @color_scheme.setter
    def color_scheme(self, color_scheme):
        """Sets the color_scheme of this DevicePreviewTargetDto.


        :param color_scheme: The color_scheme of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._color_scheme = color_scheme

    @property
    def status(self):
        """Gets the status of this DevicePreviewTargetDto.  # noqa: E501


        :return: The status of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DevicePreviewTargetDto.


        :param status: The status of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["WAITING", "READY_TO_CAPTURE", "CAPTURING", "READY", "FAILED", "NEEDS_INTERVENTION"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def failure_code(self):
        """Gets the failure_code of this DevicePreviewTargetDto.  # noqa: E501


        :return: The failure_code of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._failure_code

    @failure_code.setter
    def failure_code(self, failure_code):
        """Sets the failure_code of this DevicePreviewTargetDto.


        :param failure_code: The failure_code of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._failure_code = failure_code

    @property
    def primary_screenshot_id(self):
        """Gets the primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501


        :return: The primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: str
        """
        return self._primary_screenshot_id

    @primary_screenshot_id.setter
    def primary_screenshot_id(self, primary_screenshot_id):
        """Sets the primary_screenshot_id of this DevicePreviewTargetDto.


        :param primary_screenshot_id: The primary_screenshot_id of this DevicePreviewTargetDto.  # noqa: E501
        :type: str
        """

        self._primary_screenshot_id = primary_screenshot_id

    @property
    def created_at(self):
        """Gets the created_at of this DevicePreviewTargetDto.  # noqa: E501


        :return: The created_at of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DevicePreviewTargetDto.


        :param created_at: The created_at of this DevicePreviewTargetDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DevicePreviewTargetDto.  # noqa: E501


        :return: The updated_at of this DevicePreviewTargetDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DevicePreviewTargetDto.


        :param updated_at: The updated_at of this DevicePreviewTargetDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewTargetDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewTargetDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxExistsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exists': 'bool',
        'soft_bounce': 'bool',
        'hard_bounce': 'bool'
    }

    attribute_map = {
        'exists': 'exists',
        'soft_bounce': 'softBounce',
        'hard_bounce': 'hardBounce'
    }

    def __init__(self, exists=None, soft_bounce=None, hard_bounce=None, local_vars_configuration=None):  # noqa: E501
        """InboxExistsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._exists = None
        self._soft_bounce = None
        self._hard_bounce = None
        self.discriminator = None

        self.exists = exists
        self.soft_bounce = soft_bounce
        self.hard_bounce = hard_bounce

    @property
    def exists(self):
        """Gets the exists of this InboxExistsDto.  # noqa: E501


        :return: The exists of this InboxExistsDto.  # noqa: E501
        :rtype: bool
        """
        return self._exists

    @exists.setter
    def exists(self, exists):
        """Sets the exists of this InboxExistsDto.


        :param exists: The exists of this InboxExistsDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and exists is None:  # noqa: E501
            raise ValueError("Invalid value for `exists`, must not be `None`")  # noqa: E501

        self._exists = exists

    @property
    def soft_bounce(self):
        """Gets the soft_bounce of this InboxExistsDto.  # noqa: E501

        Inbox is full or simulating a soft bounce via inbox replier or rulesets  # noqa: E501

        :return: The soft_bounce of this InboxExistsDto.  # noqa: E501
        :rtype: bool
        """
        return self._soft_bounce

    @soft_bounce.setter
    def soft_bounce(self, soft_bounce):
        """Sets the soft_bounce of this InboxExistsDto.

        Inbox is full or simulating a soft bounce via inbox replier or rulesets  # noqa: E501

        :param soft_bounce: The soft_bounce of this InboxExistsDto.  # noqa: E501
        :type: bool
        """

        self._soft_bounce = soft_bounce

    @property
    def hard_bounce(self):
        """Gets the hard_bounce of this InboxExistsDto.  # noqa: E501

        Inbox is blocking receiving emails or simulating a hard bounce via inbox replier or rulesets  # noqa: E501

        :return: The hard_bounce of this InboxExistsDto.  # noqa: E501
        :rtype: bool
        """
        return self._hard_bounce

    @hard_bounce.setter
    def hard_bounce(self, hard_bounce):
        """Sets the hard_bounce of this InboxExistsDto.

        Inbox is blocking receiving emails or simulating a hard bounce via inbox replier or rulesets  # noqa: E501

        :param hard_bounce: The hard_bounce of this InboxExistsDto.  # noqa: E501
        :type: bool
        """

        self._hard_bounce = hard_bounce

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxExistsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxExistsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.api_audit_log_controller_api import ApiAuditLogControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestApiAuditLogControllerApi(unittest.TestCase):
    """ApiAuditLogControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.api_audit_log_controller_api.ApiAuditLogControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_audit_log_by_event_id(self):
        """Test case for get_audit_log_by_event_id

        """
        pass

    def test_get_audit_logs(self):
        """Test case for get_audit_logs

        """
        pass

    def test_search_audit_logs(self):
        """Test case for search_audit_logs

        """
        pass


if __name__ == '__main__':
    unittest.main()
